dot-dose_df: Build a prediction data frame for a specific dose value

.dose_dfR Documentation

Build a prediction data frame for a specific dose value

Description

Returns a copy of data with the treatment variable set to dose, used to predict counterfactual mediator and outcome means under intervention.

Usage

.dose_df(data, treat_var, dose)

Arguments

data

Original data frame.

treat_var

Treatment variable name.

dose

Scalar dose value.

Value

Data frame with treat_var replaced by dose.


RobustMediate documentation built on April 16, 2026, 5:08 p.m.