| plot_meditcv | R Documentation |
Produces a two-panel pathway-specific robustness corridor plot showing the observed partial correlation, critical partial correlation threshold, medITCV corridor, and benchmark confounder impacts for each pathway.
plot_meditcv(x, ...)
x |
A |
... |
Ignored. |
A ggplot2 object.
data(sim_mediation)
fit <- robustmediate(
X ~ Z1 + Z2, M ~ X + Z1 + Z2, Y ~ X + M + Z1 + Z2,
data = sim_mediation, R = 20, verbose = FALSE
)
med <- sensitivity_meditcv(fit)
plot_meditcv(med)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.