plot_meditcv_profile: Plot the medITCV Robustness Profile

View source: R/meditcv.R

plot_meditcv_profileR Documentation

Plot the medITCV Robustness Profile

Description

Visualises how each pathway's partial correlation is attenuated as confounding impact delta increases, with tipping points and a fragility zone marked.

Usage

plot_meditcv_profile(x, ...)

Arguments

x

A meditcv_profile object from sensitivity_meditcv_profile().

...

Ignored.

Value

A ggplot2 object.

Examples


data(sim_mediation)
  fit <- robustmediate(
    X ~ Z1 + Z2, M ~ X + Z1 + Z2, Y ~ X + M + Z1 + Z2,
    data = sim_mediation, R = 20, verbose = FALSE
  )
mp  <- sensitivity_meditcv_profile(fit)
plot_meditcv_profile(mp)



RobustMediate documentation built on April 16, 2026, 5:08 p.m.