| tipping_table | R Documentation |
Returns a formatted data frame of sensitivity tipping points: the minimum E-value and minimum |rho| required to nullify the NIE. Designed for direct insertion into a table in a manuscript.
tipping_table(x)
x |
A |
A data frame with columns parameter, tipping_value,
interpretation.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.