| diagnose | R Documentation |
Prints a formatted diagnostics report covering balance, mediation effects, and sensitivity robustness. The output is structured so that it can be used directly (or with minimal editing) in the Results section of an applied paper. Returns the underlying results invisibly.
diagnose(x, ...)
x |
A |
... |
Ignored. |
Invisibly returns a list with elements balance, effects,
sensitivity, meditcv, and meditcv_profile.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.