| .dose_df | R Documentation |
Returns a copy of data with the treatment variable set to dose, used
to predict counterfactual mediator and outcome means under intervention.
.dose_df(data, treat_var, dose)
data |
Original data frame. |
treat_var |
Treatment variable name. |
dose |
Scalar dose value. |
Data frame with treat_var replaced by dose.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.