| plot_meditcv_profile | R Documentation |
Visualises how each pathway's partial correlation is attenuated as confounding impact delta increases, with tipping points and a fragility zone marked.
plot_meditcv_profile(x, ...)
x |
A |
... |
Ignored. |
A ggplot2 object.
data(sim_mediation)
fit <- robustmediate(
X ~ Z1 + Z2, M ~ X + Z1 + Z2, Y ~ X + M + Z1 + Z2,
data = sim_mediation, R = 20, verbose = FALSE
)
mp <- sensitivity_meditcv_profile(fit)
plot_meditcv_profile(mp)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.